function [Q,cfx,st]=GaussLeg(funfcn,a,b,n,trace)
%---------------------------------------------------------------------------
%  Q=GaussLeg(funfcn,a,b,n,m,trace)
%  The function GaussLegendre calculates an approximate value of the        
%  integral from a function f(x) in the interval [-1,1] by the Gauss-       
%  -Legendre quadrature formula.                                            
%  Data:                                                                    
%    a,b   - the ends of the integration interval, 
%    funfcn - a  name of function which for the given vector x calculates the value 
%             of integrand at x,                                                 
%    n - number of nodes minus 1 (the nodes are numbered from 0 to n),      
%    trace - if 1 then traces the function evaluations with a point plot of the integrand  
%            the value of k-th coefficient, where k=0,1,...,floor(n/2). 
% Note: trace is shrewd parameter, so it isn't necessary to define
% 	it (trace=0 by default)
% Result:                                                                  
%    Q=GaussLeg('f',a,b,n,trace) - approximate value of the integral.               	
%  Other parameters:                                                        
%    st - a variable which within the function GaussLeg is assigned    
%         the value of:                                                     
%           1, if n<1,                                                      
%           0, otherwise.                                                   
%         Note: If st=1, then GaussLeg('f',a,b,n,trace) is not calculated.              
%    coeff - an array of coefficients of interpolation polynomial (the element f[i] contains  
%        the value of coefficient before x.^(n-i); i=0,1,...,n). 	
%---------------------------------------------------------------------------
if nargin < 4, n=8; trace = 0; end
if nargin < 5, trace = 0; end
trace1=1;

rootab= [-0.5773502691896258 0 0 0 0 0 0 0;
	 -0.7745966692414834 0 0 0 0 0 0 0; 
	 -0.8611363115940526 -0.3399810435848563 0 0 0 0 0 0;
	 -0.9061798459386640 -0.5384693101056831 0 0 0 0 0 0;
	 -0.9324695142031520 -0.6612093864662645 -0.2386191860831969 0 0 0 0 0;
	 -0.9491079123427585 -0.7415311855993944 -0.4058451513773972 0 0 0 0 0;
	 -0.9602898564975362 -0.7966664774136267 -0.5255324099163290 -0.1834346424956498 0 0 0 0;
	 -0.9681602395076261 -0.8360311073266358 -0.6133714327005904 -0.3242534234038089 0 0 0 0;
	 -0.9739065285171717 -0.8650633666889845 -0.6794095682990244 -0.4333953941292472 -0.1488743389816312 0 0 0;
	 -0.9782286581460570 -0.8870625997680953 -0.7301520055740493 -0.5190961292068118 -0.2695431559523450 0 0 0];
if a==b trace=0; end
if (n>0)&(n<100)
    st=0;s=0;l=floor(n/2);
    if n>10
      p0=1;
      x1=-1:(2/(n+1)):1;
      p1=x1;
      for j=1:n
        p2=((2*j+1)*x1.*p1-j*p0)/(j+1);
        p0=p1;
        p1=p2;
      end
      veccfx=newcoeff(n+1,x1,p2);
      rootvec=roots1(veccfx).';
    else
      for k=0:n
        if (k<=l) 
          rootvec(k+1)=rootab(n,k+1);
        else
          rootvec(k+1)=-rootab(n,n-k+1);
        end        
      end
    end 
    p0=1;
    x1=rootvec;
    p1=x1;
    for j=1:n-1
      p2=((2*j+1).*x1.*p1-j*p0)/(j+1);
      p0=p1;
      p1=p2;
    end
    x1=-2*feval(funfcn,0.5*(a+b)+0.5*(b-a).*x1).*(x1.*x1-1)./((n+1)*(n+1).*p1.*p1);	
    s=sum(x1);
    Q=0.5*(b-a)*s;
else st=1;
end

if (trace)&(st==0)
  nrfig=figure('name','Gauss-Legendre');
  clf, %whitebg
  x= a:0.01*(b-a):b;
  y=feval(funfcn,x);
  fplot(funfcn,[min([a b]) max([a b])]),%axis([a b min(y) max(y)])
  title(['Funkcja podcakowa w przedziale (',num2str(a,9),';',num2str(b,9),')']); 
  pause
  vecxx=-1:0.01:1;
  vecyy=0.5*(b-a)*feval(funfcn,0.5*(a+b)+0.5*(b-a)*vecxx);
  clf, plot(vecxx,vecyy),grid,title('Przeskalowanie do przedziau (-1,1)');
  handle=line([-1 1],[0 0]);if get(gcf,'color')==[0 0 0] kolor='white'; else kolor='black';end
  set(handle,'color',kolor),pause;
  hold on;
  vecx=rootvec;
  vecy=0.5*(b-a)*feval(funfcn,0.5*(a+b)+0.5*(b-a)*vecx);
  plot(vecx,vecy,'ro'),title('Wzy kwadratury (press Enter)'),pause 
  cfx=newcoeff(n,vecx,vecy);
  vecfx=0;
  for k=0:n
  vecfx=vecfx+cfx(n-k+1).*vecxx.^k;
  end	
  plot(vecxx,vecfx,'b-'),title('Interpolacja (press Enter)'),pause
  end
  title(['Wynik cakowania= ',num2str(Q,9)]),pause
  hold off
  close	
end
