function [Q,cfx,st]=NewCotes(funfcn,a,b,n,m,trace)
%---------------------------------------------------------------------------
%  Q=NewCotes(funfcn,a,b,n,m,trace)	
%  The function NewCotes calculates an approximate value of the      
%  integral from a function f(x) in a finite interval [a,b] by the          
%  composite Newton-Cotes quadrature formula.                               
%  Data:                                                                    
%    a,b   - the ends of the integration interval,                          
%    funfcn- a string containig the name of the function,                                        
%    m     - number of subintervals of [a,b],                               
%    n     - number of subintervals in each interval [a+ih,a+(i+1)h]        
%            (i=0,1,...,m-1),                                                                  
%    trace - if 1 then traces the function evaluations with a point plot of the integrand  
%            the value of k-th coefficient,     
% Note: n,m & trace are shrewd parameters, so it isn't necessary to define
% 	them (n=1 m=1,trace=0 by default)
%  Result:                                                                  
%  NewCotes('f',a,b,n,m,trace)=Q - approximate value of the integral.                     
%  Other parameters:                                                        
%    st - a variable which within the function NewCotes is assigned  
%         the value of:                                                     
%           1, if m<1 or n<1,                                               
%           0, otherwise.                                                   
%  Note: If st=1, then NewCotes(funfcn,a,b,n,m,trace) is not calculated.                                             
%    coeff - an array of coefficients of interpolation polynomial (the element f[i] contains  
%        the value of coefficient before x.^(n-i); i=0,1,...,n). 	
%---------------------------------------------------------------------------
if nargin < 4, n=1;m=1; trace = 0; end
if nargin < 5, m=1;trace = 0; end
if nargin < 6, trace = 0; end

alpha=	[1 1 0 0 0 0 0 0;
	 1 4 1 0 0 0 0 0;
	 1 3 3 1 0 0 0 0;
	 7 32 12 32 7 0 0 0;
	 19 75 50 50 75 19 0 0;
	 41 216 27 272 27 216 41 0;
	 1752.33 8346.24 3086.784 6974.208 6974.208 3086.784 8346.24 1752.33];
nrho=	[2 6 8 90 288 840 40320];
if a==b trace=0; end
if (m>0) & (n>0) & (n<8)
  st=0;
  h=(b-a)/m;
  s=0;
  for i=0:m-1
    for k=0:n
      y=feval(funfcn,a+(i+k/n)*h);
      s=s+alpha(n,k+1)*y;
    end
  end
  Q=h*s/nrho(n);
else st=1;
end

if (trace)&(st==0)
	nrfig=figure('name','Newton-Cotes');
	clf, %whitebg
	x= a:0.01*(b-a):b;
	y=feval(funfcn,x);
	fplot(funfcn,[min([a b]) max([a b])]),%axis([a b min(y) max(y)])
        title(['Funkcja podcakowa w przedziale (',num2str(a,9),';',num2str(b,9),')']); 
	handle=line([a b],[0 0]);
	if get(gcf,'color')==[0 0 0] kolor='white'; else kolor='black';end
        set(handle,'color',kolor);
	pause
	hold on
	if m>1
   		vecx=(a+h):h:(a+(m-1)*h);
		vecy=feval(funfcn,vecx); 
		for i=1:m-1
		handle=line([vecx(i) vecx(i)],[0 vecy(i)]);
		set(handle,'color','g')
		end
	title('Przedziay kwadratury zoonej (press Enter)')
	pause
	end
	for i=0:m-1
		vecx=(a+i*h):((1/n)*h):(a+(i+1)*h);
		vecy=feval(funfcn,vecx); 
		plot(vecx,vecy,'ro')
	end
	title('Wzy kwadratury (press Enter)')
	pause
	for i=0:m-1
   		vecxx=a+i*h:0.1*(1/n)*h:a+(i+1)*h;
		vecx=(a+i*h):((1/n)*h):(a+(i+1)*h);
		vecy=feval(funfcn,vecx); 
		%vecfx=lagrange(vecxx,vecx,vecy,n);	
		cfx=newcoeff(n,vecx,vecy);
		vecfx=0;
		for k=0:n
		    vecfx=vecfx+cfx(n-k+1).*vecxx.^k;
		end
		plot(vecxx,vecfx,'b-')
	end	
	title('Interpolacja (press Enter)'),pause
	title(['Wynik cakowania= ',num2str(Q,9)]),pause
	hold off
	close
end